use utoipa::{
    openapi::security::{ApiKey, ApiKeyValue, HttpAuthScheme, HttpBuilder, SecurityScheme},
    Modify, OpenApi,
};

pub const AUTH_TAG: &str = "Authentication";
pub const USERS_TAG: &str = "Users";
pub const ORDER_TAG: &str = "Orders";
pub const API_KEY_TAG: &str = "API Keys";
pub const SIGNATURE_TAG: &str = "Signature";
pub const FILE_TAG: &str = "Files";
pub const DEPARTMENTS_TAG: &str = "Departments";
pub const UNITS_TAG: &str = "Units";
pub const VENDORS_TAG: &str = "Vendors";
pub const DATA_HUB_TAG: &str = "Data Hub";

#[derive(OpenApi)]
#[openapi(
    modifiers(&SecurityAddon),
    tags(
        (name = AUTH_TAG, description = "API Authentication endpoints"),
        (name = FILE_TAG, description = "Upload and Download Files"),
        (name = ORDER_TAG, description = "Order API endpoints"),
        (name = API_KEY_TAG, description = "API Key endpoints"),
        (name = SIGNATURE_TAG, description = "API endpoints for signing"),
        (name = FILE_TAG, description = "File attachment API endpoints"),
        (name = DEPARTMENTS_TAG, description = "Departments API endpoints"),
        (name = UNITS_TAG, description = "Units API endpoints"),
        (name = VENDORS_TAG, description = "Vendors API endpoints"),
        (name = DATA_HUB_TAG, description = "Data Hub API endpoints")
    ),
)]
pub struct ApiDocumentation;

struct SecurityAddon;

impl Modify for SecurityAddon {
    fn modify(&self, openapi: &mut utoipa::openapi::OpenApi) {
        if let Some(components) = openapi.components.as_mut() {
            components.add_security_scheme(
                "api_key",
                SecurityScheme::ApiKey(ApiKey::Header(ApiKeyValue::new("x-api-key"))),
            );
            components.add_security_scheme(
                "user_auth",
                SecurityScheme::Http(
                    HttpBuilder::new()
                        .scheme(HttpAuthScheme::Bearer)
                        .bearer_format("JWT")
                        .build(),
                ),
            );
        }
    }
}
