use axum::{debug_handler, extract::Query, Extension};
use serde::Deserialize;
use utoipa::IntoParams;

use crate::{
    api::{backend::ApiBackend, description::API_KEY_TAG, routes::api_keys::sql},
    errors::ApiError,
};

#[derive(Debug, Deserialize, IntoParams)]
pub struct DeleteQueryParameters {
    key_id: String,
}

#[debug_handler]
#[utoipa::path(
    delete,
    path = "/apikeys",
    summary = "Delete API Key",
    description = "Delete an API Key.",
    params(DeleteQueryParameters),
    responses(
        (status = OK, description = "API Key successfully deleted"),
    ),
    security(
        ("user_auth" = ["write:apikeys",]),
    ),
    tag = API_KEY_TAG)]
pub async fn delete_api_key(
    Extension(backend): Extension<ApiBackend>,
    Query(params): Query<DeleteQueryParameters>,
) -> Result<(), ApiError> {
    sql::delete_api_key(backend.pool(), &params.key_id).await?;
    Ok(())
}
