use axum::{debug_handler, Extension, Json};

use crate::{
    api::{
        backend::ApiBackend,
        description::API_KEY_TAG,
        routes::api_keys::{models::ApiKey, sql},
    },
    errors::ApiError,
};

#[debug_handler]
#[utoipa::path(
    put,
    path = "/apikeys",
    summary = "Update API Key",
    description = "Update an API Key.",
    request_body(content = ApiKey, description = "API Key details", content_type = "application/json"),
    responses(
        (status = OK, description = "API Key successfully updated"),
    ),
    security(
        ("user_auth" = ["write:apikeys",]),
    ),
    tag = API_KEY_TAG)]
pub async fn update_api_key(
    Extension(backend): Extension<ApiBackend>,
    Json(api_key): Json<ApiKey>,
) -> Result<(), ApiError> {
    sql::update_api_key(backend.pool(), &api_key).await?;
    Ok(())
}
