use utoipa_axum::{router::OpenApiRouter, routes};

use crate::{
    api::routes::users::permissions::{Permission, PermissionDetail},
    permission_required,
};
use handlers::apikeys_delete::{__path_delete_api_key, delete_api_key};
use handlers::apikeys_get::{__path_get_api_keys, get_api_keys};
use handlers::apikeys_post::{__path_create_api_key, create_api_key};
use handlers::apikeys_put::{__path_update_api_key, update_api_key};

mod handlers;
pub mod models;
pub mod sql;

// expose the OpenAPI to parent module
pub fn router() -> OpenApiRouter {
    let read = OpenApiRouter::new()
        .routes(routes!(get_api_keys))
        .route_layer(permission_required!(Permission::Read(
            PermissionDetail::APIKeys
        )));
    let write = OpenApiRouter::new()
        .routes(routes!(create_api_key, update_api_key, delete_api_key))
        .route_layer(permission_required!(Permission::Write(
            PermissionDetail::APIKeys
        )));

    OpenApiRouter::new().merge(read).merge(write)
}
