use axum::response::sse;
use serde::Serialize;
use tokio::sync::broadcast::{self, Receiver, Sender};
use ts_rs::TS;
use utoipa::ToSchema;

use crate::api::routes::{units::models::Unit, vendors::models::Vendor};

#[derive(Debug, Clone, Serialize, ToSchema)]
pub struct DataHubStream {
    /// Unique identifier for the data update event
    id: String,
    /// Event Type (always 'Message')
    event: String,
    /// Data content
    data: DataHubData,
}

#[derive(Debug)]
pub struct DataHub {
    pub sender: Sender<DataHubData>,
    pub receiver: Receiver<DataHubData>,
}

impl DataHub {
    pub fn new() -> Self {
        let (sender, receiver) = broadcast::channel(15);

        Self {
            sender,
            receiver: receiver,
        }
    }
}

#[derive(Debug, Clone, Serialize, TS, ToSchema)]
#[ts(export)]
#[serde(tag = "type", content = "data")]
pub enum DataHubData {
    Units(Vec<Unit>),
    Vendors(Vec<Vendor>),
}

impl From<DataHubData> for sse::Event {
    fn from(value: DataHubData) -> Self {
        sse::Event::default()
            // .event(event_type.to_string())
            .data(serde_json::to_string(&value).unwrap_or_default())
    }
}
