use axum::{debug_handler, Extension, Json};

use super::super::sql;
use crate::{
    api::{
        backend::ApiBackend, description::DEPARTMENTS_TAG, routes::departments::models::Department,
    },
    errors::ApiError,
};

#[debug_handler]
#[utoipa::path(
    get,
    path = "/departments",
    summary = "Get all Departments",
    description = "Get a list of all Departments.",
    responses(
        (status = OK, body = Vec<Department>, description = "List of departments"),
    ),
    security(
        ("user_auth" = ["read:departments",]),
    ),
    tag = DEPARTMENTS_TAG)]
pub async fn get_departments(
    Extension(backend): Extension<ApiBackend>,
) -> Result<Json<Vec<Department>>, ApiError> {
    Ok(Json(sql::get_departments(backend.pool(), None).await?))
}
