use axum::{debug_handler, Extension, Json};
use validator::Validate;

use super::super::sql;
use crate::{
    api::{
        backend::ApiBackend, description::DEPARTMENTS_TAG, routes::departments::models::Department,
    },
    errors::ApiError,
};

#[debug_handler]
#[utoipa::path(
    post,
    path = "/departments",
    summary = "Create new Department",
    description = "Create new Department.",
    responses(
        (status = OK, description = "Creation succeeded"),
    ),
    security(
        ("user_auth" = ["write:departments",]),
    ),
    tag = DEPARTMENTS_TAG)]
pub async fn create_department(
    Extension(backend): Extension<ApiBackend>,
    Json(department): Json<Department>,
) -> Result<(), ApiError> {
    // validate request
    department.validate()?;
    // insert new department
    sql::create_department(backend.pool(), department).await
}
