use axum::{debug_handler, Extension, Json};
use validator::Validate;

use super::super::sql;
use crate::{
    api::{
        backend::ApiBackend, description::DEPARTMENTS_TAG, routes::departments::models::Department,
    },
    errors::ApiError,
};

#[debug_handler]
#[utoipa::path(
    put,
    path = "/departments",
    summary = "Update Department",
    description = "Change details of Departments.",
    responses(
        (status = OK, description = "Update succeeded"),
    ),
    security(
        ("user_auth" = ["write:departments",]),
    ),
    tag = DEPARTMENTS_TAG)]
pub async fn update_department(
    Extension(backend): Extension<ApiBackend>,
    Json(department): Json<Department>,
) -> Result<(), ApiError> {
    // validate request
    department.validate()?;
    // insert new department
    sql::update_department(backend.pool(), department).await
}
