use utoipa_axum::{router::OpenApiRouter, routes};

use crate::{
    api::routes::users::permissions::{Permission, PermissionDetail},
    login_required, permission_required,
};

use handlers::departments_get::*;
use handlers::departments_post::*;
use handlers::departments_put::*;

mod handlers;
pub mod models;
pub mod sql;

// expose the OpenAPI to parent module
pub fn router() -> OpenApiRouter {
    let read = OpenApiRouter::new()
        .routes(routes!(get_departments))
        .route_layer(login_required!());
    let write = OpenApiRouter::new()
        .routes(routes!(create_department, update_department))
        .route_layer(permission_required!(Permission::Write(
            PermissionDetail::Departments
        )));

    OpenApiRouter::new().merge(read).merge(write)
}
