pub mod handlers;
mod models;
mod sql;

use axum::extract::DefaultBodyLimit;
use utoipa_axum::{router::OpenApiRouter, routes};

use crate::login_required;

use handlers::{
    files_draft_delete::*, files_draft_get::*, files_draft_post::*, files_file_get::*,
    files_order_bundle_get::*, files_order_get::*, files_order_post::*,
};

const FILE_SIZE_LIMIT_MB: usize = 20;

// expose the OpenAPI to parent module
pub fn router() -> OpenApiRouter {
    OpenApiRouter::new()
        .routes(routes!(get_specified_file))
        .routes(routes!(get_attached_order_files_zip_bundle))
        .routes(routes!(
            upload_draft_file,
            get_attached_draft_files,
            delete_draft_file
        ))
        .routes(routes!(upload_order_file, get_attached_order_files))
        .layer(DefaultBodyLimit::max(FILE_SIZE_LIMIT_MB * 1000 * 1000))
        .route_layer(login_required!())
}
