use utoipa_axum::{router::OpenApiRouter, routes};

use crate::{
    api::routes::users::permissions::{Permission, PermissionDetail},
    permission_required,
};

use handlers::signature_key_get::*;
use handlers::signature_key_post::*;
use handlers::signature_key_put::*;
use handlers::signature_sign_post::*;
use handlers::signature_verify_get::*;

mod handlers;
pub mod models;
pub mod sql;

// expose the OpenAPI to parent module
pub fn router() -> OpenApiRouter {
    let verify = OpenApiRouter::new().routes(routes!(verify));
    let write = OpenApiRouter::new()
        .routes(routes!(
            check_signing_key,
            create_signing_key,
            verify_signing_key
        ))
        .routes(routes!(sign))
        .route_layer(permission_required!(Permission::Write(
            PermissionDetail::Signature
        )));

    OpenApiRouter::new().merge(write).merge(verify)
}
