use sqlx::PgPool;

use crate::{
    api::routes::signature::models::{KeyData, PublicKeyID},
    errors::ApiError,
};

pub async fn get_private_key(pool: &PgPool, user_id: &str) -> Result<KeyData, ApiError> {
    Ok(sqlx::query_as!(
        KeyData,
        r#"SELECT
            USERS."PrivateKey" as key
        FROM
            users
        WHERE USERS."UserID" = $1"#,
        user_id
    )
    .fetch_one(pool)
    .await?)
}

pub async fn update_private_key(
    pool: &PgPool,
    user_id: &str,
    private_key: String,
) -> Result<(), ApiError> {
    sqlx::query!(
        r#"UPDATE users SET
            "PrivateKey" = $2
        WHERE "UserID" = $1"#,
        user_id,
        private_key
    )
    .execute(pool)
    .await?;

    Ok(())
}

pub async fn store_public_key(
    pool: &PgPool,
    user_id: &str,
    public_key: String,
) -> Result<(), ApiError> {
    sqlx::query!(
        r#"INSERT INTO "PublicKeys"
            ("UserID", "PublicKey")
            VALUES ($1, $2)"#,
        user_id,
        public_key
    )
    .execute(pool)
    .await?;

    Ok(())
}

pub async fn get_current_public_key(
    pool: &PgPool,
    user_id: &str,
) -> Result<Option<PublicKeyID>, ApiError> {
    Ok(sqlx::query_as!(
        PublicKeyID,
        r#"SELECT 
            "PublicKeys"."Timestamp" as timestamp,
            "PublicKeys"."UserID" as user_id
        FROM 
            "PublicKeys"
        WHERE
            "PublicKeys"."UserID" = $1
        ORDER BY timestamp DESC"#,
        user_id,
    )
    .fetch_optional(pool)
    .await?)
}

pub async fn get_public_key_by_id(pool: &PgPool, key_id: PublicKeyID) -> Result<KeyData, ApiError> {
    Ok(sqlx::query_as!(
        KeyData,
        r#"SELECT 
            "PublicKeys"."PublicKey" as key
        FROM 
            "PublicKeys"
        WHERE
            "PublicKeys"."UserID" = $1
            AND "PublicKeys"."Timestamp" = $2"#,
        key_id.user_id,
        key_id.timestamp,
    )
    .fetch_one(pool)
    .await?)
}
