use axum::{debug_handler, Extension, Json};

use super::super::sql;
use crate::{
    api::{backend::ApiBackend, description::UNITS_TAG, routes::units::models::Unit},
    errors::ApiError,
};

#[debug_handler]
#[utoipa::path(
    get,
    path = "/units",
    summary = "Get all Units",
    description = "Get a list of all Units.",
    responses(
        (status = OK, body = Vec<Unit>, description = "List of Units"),
    ),
    security(
        ("user_auth" = ["read:units",]),
    ),
    tag = UNITS_TAG)]
pub async fn get_units(
    Extension(backend): Extension<ApiBackend>,
) -> Result<Json<Vec<Unit>>, ApiError> {
    Ok(Json(sql::get_units(backend.pool(), None).await?))
}
