use std::sync::Arc;

use axum::{debug_handler, Extension, Json};

use super::super::sql;
use crate::{
    api::{
        backend::ApiBackend,
        description::UNITS_TAG,
        routes::{
            data_hub::models::{DataHub, DataHubData},
            units::models::Unit,
        },
    },
    errors::ApiError,
};

#[debug_handler]
#[utoipa::path(
    post,
    path = "/units",
    summary = "Create new Unit",
    description = "Create new Unit.",
    responses(
        (status = OK, description = "Creation succeeded"),
    ),
    security(
        ("user_auth" = ["write:units",]),
    ),
    tag = UNITS_TAG)]
pub async fn create_unit(
    Extension(backend): Extension<ApiBackend>,
    Extension(data_hub): Extension<Arc<DataHub>>,
    Json(unit): Json<Unit>,
) -> Result<(), ApiError> {
    // insert new unit
    sql::create_unit(backend.pool(), unit).await?;

    // get updated unit list
    let units = sql::get_units(backend.pool(), None).await?;
    let _ = data_hub.sender.send(DataHubData::Units(units));

    Ok(())
}
