use axum::{debug_handler, Extension, Json};

use super::super::sql;
use crate::{
    api::{backend::ApiBackend, description::UNITS_TAG, routes::units::models::Unit},
    errors::ApiError,
};

#[debug_handler]
#[utoipa::path(
    put,
    path = "/units",
    summary = "Update Unit",
    description = "Change details of Units.",
    responses(
        (status = OK, description = "Update succeeded"),
    ),
    security(
        ("user_auth" = ["write:units",]),
    ),
    tag = UNITS_TAG)]
pub async fn update_unit(
    Extension(backend): Extension<ApiBackend>,
    Json(unit): Json<Unit>,
) -> Result<(), ApiError> {
    sql::update_unit(backend.pool(), unit).await
}
