use sqlx::PgPool;

use crate::{api::routes::models::Status, errors::ApiError};

use super::models::Unit;

pub async fn get_units(
    pool: &PgPool,
    filter_active: Option<Status>,
) -> Result<Vec<Unit>, ApiError> {
    Ok(sqlx::query_as!(
        Unit,
        r#"SELECT
            UNITS."UnitID" as id,
            UNITS."Display" as display,
            UNITS."Description" as description,
            UNITS."Abbreviation" as abbreviation,
            UNITS."Status" as "status: Status"
        FROM
            units
        WHERE
            ($1::smallint IS NULL OR UNITS."Status" = $1)"#,
        filter_active.map(|v| v as i16),
    )
    .fetch_all(pool)
    .await?)
}

pub async fn create_unit(pool: &PgPool, unit: Unit) -> Result<(), ApiError> {
    let mut transaction = pool.begin().await?;

    sqlx::query!(
        r#"INSERT INTO units
        ("Display", "Description", "Status", "Abbreviation") 
        VALUES ($1, $2, $3, $4)"#,
        unit.display,
        unit.description,
        unit.status as i16,
        unit.abbreviation
    )
    .execute(&mut *transaction)
    .await?;

    // commit transaction
    transaction.commit().await?;

    Ok(())
}

pub async fn update_unit(pool: &PgPool, unit: Unit) -> Result<(), ApiError> {
    let mut transaction = pool.begin().await?;

    sqlx::query!(
        r#"UPDATE units SET
            "Display" = $2,
            "Description" = $3,
            "Status" = $4,
            "Abbreviation" = $5
        WHERE "UnitID" = $1"#,
        unit.id,
        unit.display,
        unit.description,
        unit.status as i16,
        unit.abbreviation
    )
    .execute(&mut *transaction)
    .await?;

    // commit transaction
    transaction.commit().await?;

    Ok(())
}
