use axum::{debug_handler, Extension, Json};

use super::super::sql;
use crate::{
    api::{backend::ApiBackend, description::USERS_TAG, routes::users::models::User},
    errors::ApiError,
};

#[debug_handler]
#[utoipa::path(
    get,
    path = "/users",
    summary = "Get all Users",
    description = "Get a list of all users.",
    responses(
        (status = OK, body = Vec<User>, description = "List of users"),
    ),
    security(
        ("user_auth" = ["read:users",]),
    ),
    tag = USERS_TAG)]
pub async fn get_users(
    Extension(backend): Extension<ApiBackend>,
) -> Result<Json<Vec<User>>, ApiError> {
    Ok(Json(sql::get_users(backend.pool(), None, None).await?))
}
