use axum::{debug_handler, Extension, Json};

use crate::{
    api::{
        backend::ApiBackend,
        description::USERS_TAG,
        routes::users::{models::User, sql},
    },
    errors::ApiError,
};

#[debug_handler]
#[utoipa::path(
    put,
    path = "/users",
    summary = "Change User details",
    description = "Update user information / permissions / groups ",
    request_body(content = User, description = "User details", content_type = "application/json"),
    responses(
        (status = OK, description = "User successfully updated"),
    ),
    security(
        ("user_auth" = ["write:users"]),
    ),
    tag = USERS_TAG)]
pub async fn update_user(
    Extension(backend): Extension<ApiBackend>,
    Json(user): Json<User>,
) -> Result<(), ApiError> {
    sql::update_user(backend.pool(), &user).await?;

    Ok(())
}
