use permissions::{Permission, PermissionDetail};
use utoipa_axum::{router::OpenApiRouter, routes};

use crate::permission_required;

use handlers::users_available_ad_get::*;
use handlers::users_get::*;
use handlers::users_post::*;
use handlers::users_put::*;

mod handlers;
pub mod models;
pub mod permissions;
pub mod sql;

// expose the OpenAPI to parent module
pub fn router() -> OpenApiRouter {
    let read = OpenApiRouter::new()
        .routes(routes!(get_users))
        .route_layer(permission_required!(Permission::Read(
            PermissionDetail::Users
        )));
    let write = OpenApiRouter::new()
        .routes(routes!(create_user, update_user))
        .routes(routes!(get_ad_users))
        .route_layer(permission_required!(Permission::Write(
            PermissionDetail::Users
        )));

    OpenApiRouter::new().merge(read).merge(write)
}
