use axum::{debug_handler, Extension, Json};

use super::super::sql;
use crate::{
    api::{backend::ApiBackend, description::VENDORS_TAG, routes::vendors::models::Vendor},
    errors::ApiError,
};

#[debug_handler]
#[utoipa::path(
    get,
    path = "/vendors",
    summary = "Get all Vendors",
    description = "Get a list of all Vendors.",
    responses(
        (status = OK, body = Vec<Vendor>, description = "List of vendors"),
    ),
    tag = VENDORS_TAG)]
pub async fn get_vendors(
    Extension(backend): Extension<ApiBackend>,
) -> Result<Json<Vec<Vendor>>, ApiError> {
    Ok(Json(sql::get_vendors(backend.pool()).await?))
}
