use utoipa_axum::{router::OpenApiRouter, routes};

use crate::{
    api::routes::users::permissions::{Permission, PermissionDetail},
    login_required, permission_required,
};

use handlers::{vendors_get::*, vendors_import_post::*};

mod handlers;
pub mod models;
pub mod sql;

// expose the OpenAPI to parent module s
pub fn router() -> OpenApiRouter {
    let read = OpenApiRouter::new()
        .routes(routes!(get_vendors))
        .route_layer(login_required!());
    let write = OpenApiRouter::new()
        .routes(routes!(import_vendors))
        .route_layer(permission_required!(Permission::Write(
            PermissionDetail::Vendors
        )));

    OpenApiRouter::new().merge(read).merge(write)
}
