use sqlx::{PgPool, Postgres, Transaction};

use crate::errors::ApiError;

use super::models::Vendor;

pub async fn get_vendors(pool: &PgPool) -> Result<Vec<Vendor>, ApiError> {
    Ok(sqlx::query_as!(
        Vendor,
        r#"SELECT 
            "VendorID" as id,
            "Name" as name
        FROM 
            vendors
        ORDER BY "Name" ASC"#
    )
    .fetch_all(pool)
    .await?)
}

pub async fn import_vendor_line(
    transaction: &mut Transaction<'static, Postgres>,
    id: &str,
    name: &str,
) -> Result<(), ApiError> {
    sqlx::query!(
        r#"INSERT INTO vendors
            ("VendorID", "Name")
        VALUES ($1, $2)
        ON CONFLICT ("VendorID") DO UPDATE
            SET "Name" = $2;
        "#,
        id,
        name
    )
    .execute(&mut **transaction)
    .await?;

    Ok(())
}
