use axum::{
    async_trait,
    extract::FromRequestParts,
    http::{request::Parts, StatusCode},
};

use super::AuthenticationBackend;

#[async_trait]
impl<S, T> FromRequestParts<S> for AuthenticationBackend<T>
where
    S: Send + Sync,
    T: Send + Sync + Clone + 'static,
{
    type Rejection = (StatusCode, &'static str);

    async fn from_request_parts(parts: &mut Parts, _state: &S) -> Result<Self, Self::Rejection> {
        parts
            .extensions
            .get::<AuthenticationBackend<T>>()
            .cloned()
            .ok_or((
                StatusCode::INTERNAL_SERVER_ERROR,
                "Can't extract auth session. Is `AuthenticationLayer` enabled?",
            ))
    }
}
