use std::{
    collections::{HashMap, HashSet},
    sync::Arc,
};

use tokio::sync::Mutex;

// use super::ApiKey;

#[derive(Debug, Clone)]
pub struct SessionStore<T> {
    active_sessions: Arc<Mutex<HashSet<String>>>,
    active_api_keys: Option<Arc<Mutex<HashMap<String, T>>>>,
}

impl<T> SessionStore<T> {
    pub fn new(initial_api_keys: Option<Vec<T>>) -> Self {
        Self {
            active_sessions: Arc::new(Mutex::new(HashSet::new())),
            active_api_keys: None, //initial_api_keys.map(|keys| {
                                   //     Arc::new(Mutex::new(HashMap::from_iter(
                                   //         keys.into_iter().map(|key| (key.id.clone(), key)),
                                   //     )))
                                   // }),
        }
    }

    pub async fn insert(&self, token: impl Into<String>) {
        let mut sessions = self.active_sessions.lock().await;
        sessions.insert(token.into());
    }

    pub async fn includes(&self, token: &str) -> bool {
        let sessions = self.active_sessions.lock().await;
        sessions.contains(token)
    }

    pub async fn remove(&self, token: &str) -> bool {
        let mut sessions = self.active_sessions.lock().await;
        sessions.remove(token)
    }

    pub async fn get_api_key(&self, key: &str) -> Option<T>
    where
        T: Clone,
    {
        if let Some(ref key_store) = self.active_api_keys {
            let lock = key_store.lock().await;
            lock.get(key).cloned()
        } else {
            None
        }
    }
}
